<?xml version="1.0" encoding="UTF-8"?>
<!--
 - Desc:    This file is part of the eCromedos document preparation system
 - Date:    2006/03/09
 - Author:  Tobias Koch (tkoch@ecromedos.net)
 - License: GNU General Public License, version 2
 - URL:     http://www.ecromedos.net
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<!--
  - Catch 'figure' node and determine context
-->
<xsl:template match="figure">
	<xsl:choose>
		<xsl:when test="ancestor::p">
			<xsl:call-template name="figure.inline"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="figure.block"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!--
  - Extract width attribute
-->
<xsl:template name="figure.width">
	<xsl:param name="width"/>
	<xsl:choose>
		<xsl:when test="substring($width, string-length($width), string-length($width)) = '%'">
			<xsl:variable name="percent">
				<xsl:value-of select="number(substring($width, 1, string-length($width) - 1))"/>
			</xsl:variable>
			<xsl:value-of select="$percent div 100.0"/>
			<xsl:text>\linewidth</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="$width"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!--
  - Set an inline figure
-->
<xsl:template name="figure.inline">

	<xsl:variable name="width">
		<xsl:choose>
			<xsl:when test="img/@print-width">
				<xsl:call-template name="figure.width">
					<xsl:with-param name="width" select="normalize-space(img/@print-width)"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>0.5\linewidth</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<xsl:text>\begin{wrapfigure}{</xsl:text>
	<xsl:choose>
		<xsl:when test="@align = 'right'">
			<xsl:text>r</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>l</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text>}[0cm]{</xsl:text>
	<xsl:value-of select="$width"/>
	<xsl:text>}&#x0a;</xsl:text>
	<xsl:text>\includegraphics[width=\linewidth]{</xsl:text>
	<xsl:value-of select="normalize-space(img/@src)"/>
	<xsl:text>}&#x0a;</xsl:text>
	<xsl:if test="caption">
		<xsl:text>\caption{</xsl:text>
		<xsl:value-of select="normalize-space(caption)"/>
		<xsl:text>}&#x0a;</xsl:text>
	</xsl:if>
	<xsl:apply-templates select="label"/>
	<xsl:text>\end{wrapfigure}</xsl:text>
</xsl:template>

<!--
  - Set a block figure
-->
<xsl:template name="figure.block">
	<xsl:text>\begin{figure}[</xsl:text>
	<xsl:choose>
		<xsl:when test="@float='yes'">
			<xsl:text>h!</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>H</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text>]&#x0a;</xsl:text>
	<xsl:choose>
		<xsl:when test="@align = 'left'">
			<xsl:text></xsl:text>
		</xsl:when>
		<xsl:when test="@align = 'right'">
			<xsl:text>\hfill{}&#x0a;</xsl:text>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>\centering{}&#x0a;</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text>\begin{minipage}{</xsl:text>
	<xsl:choose>
		<xsl:when test="img/@print-width">
			<xsl:call-template name="figure.width">
				<xsl:with-param name="width" select="normalize-space(img/@print-width)"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>1.0\linewidth</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:text>}&#x0a;</xsl:text>
	<xsl:text>\includegraphics[width=1.0\linewidth]{</xsl:text>
	<xsl:value-of select="normalize-space(img/@src)"/>
	<xsl:text>}&#x0a;</xsl:text>
	<xsl:if test="caption">
		<xsl:text>\caption{</xsl:text>
		<xsl:value-of select="normalize-space(caption)"/>
		<xsl:text>}&#x0a;</xsl:text>
	</xsl:if>
	<xsl:apply-templates select="label"/>
	<xsl:text>\end{minipage}&#x0a;</xsl:text>
	<xsl:text>\end{figure}&#x0a;</xsl:text>
</xsl:template>

</xsl:stylesheet>
